==> tigase-server-8.0.0-sources.jar: tigase/auth/adhoc/AddUserCredentials.java <==
/**
 * Tigase XMPP Server - The instant messaging server
 * Copyright (C) 2004 Tigase, Inc. (office@tigase.com)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */
package tigase.auth.adhoc;

import tigase.auth.credentials.Credentials;
import tigase.component.adhoc.AdHocCommandException;
import tigase.component.adhoc.AdHocResponse;
import tigase.component.adhoc.AdhHocRequest;
import tigase.db.TigaseDBException;
import tigase.form.Field;
import tigase.form.Form;
import tigase.kernel.beans.Bean;
import tigase.server.xmppsession.SessionManager;
import tigase.xmpp.Authorization;
import tigase.xmpp.jid.BareJID;

@Bean(name = AddUserCredentials.NODE, parent = SessionManager.class, active = true)
public class AddUserCredentials
		extends AbstractCredentialsCommand {

	public static final String NODE = "auth-credentials-add";

	public AddUserCredentials() {
	}

	@Override
	public String getName() {
		return "Add user credentials";
	}

	@Override
	public String getNode() {
		return NODE;
	}

	@Override
	protected void processForm(Form form, AdhHocRequest request, AdHocResponse response)
			throws TigaseDBException, AdHocCommandException {
		BareJID jid = BareJID.bareJIDInstanceNS(form.getAsString(FIELD_JID));

		checkIfCanModifyJID(request, jid);

		String username = form.getAsString(FIELD_USERNAME);
		String password = form.getAsString(FIELD_PASSWORD);

		if (username == null || username.trim().isEmpty()) {
			username = Credentials.DEFAULT_USERNAME;
		}

		if (password == null || username.isEmpty()) {
			throw new AdHocCommandException(Authorization.BAD_REQUEST, "Passwor cannot be null");
		}

		Form resp = new Form("result", null, null);

		authRepository.updateCredential(jid, username.trim(), password);

		resp.addField(Field.fieldFixed("OK"));

		response.getElements().add(resp.getElement());
		response.completeSession();
	}

	@Override
	protected void processNoForm(AdhHocRequest request, AdHocResponse response) {
		Form form = new Form("form", getName(), null);

		form.addField(Field.fieldJidSingle(FIELD_JID, null, "The Jabber ID for the account"));
		form.addField(Field.fieldJidSingle(FIELD_USERNAME, null, "Username"));
		form.addField(Field.fieldJidSingle(FIELD_PASSWORD, null, "Password"));

		response.startSession();
		response.getElements().add(form.getElement());
	}
}

==> tigase-server-8.5.0-20251009.101847-83-sources.jar: tigase/auth/adhoc/AddUserCredentials.java <==
/*
 * Tigase XMPP Server - The instant messaging server
 * Copyright (C) 2004 Tigase, Inc. (office@tigase.com)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */
package tigase.auth.adhoc;

import tigase.auth.credentials.Credentials;
import tigase.component.adhoc.AdHocCommandException;
import tigase.component.adhoc.AdHocResponse;
import tigase.component.adhoc.AdhHocRequest;
import tigase.db.TigaseDBException;
import tigase.form.Field;
import tigase.form.Form;
import tigase.kernel.beans.Bean;
import tigase.server.xmppsession.SessionManager;
import tigase.xmpp.Authorization;
import tigase.xmpp.jid.BareJID;

@Bean(name = AddUserCredentials.NODE, parent = SessionManager.class, active = true)
public class AddUserCredentials
		extends AbstractCredentialsCommand {

	public static final String NODE = "auth-credentials-add";

	public AddUserCredentials() {
	}

	@Override
	public String getName() {
		return "Add user credentials";
	}

	@Override
	public String getNode() {
		return NODE;
	}

	@Override
	protected void processForm(Form form, AdhHocRequest request, AdHocResponse response)
			throws TigaseDBException, AdHocCommandException {
		BareJID jid = BareJID.bareJIDInstanceNS(form.getAsString(FIELD_JID));

		checkIfCanModifyJID(request, jid);

		String credentialId = form.getAsString(FIELD_CREDENTIAL_ID);
		String password = form.getAsString(FIELD_PASSWORD);

		if (credentialId == null || credentialId.trim().isEmpty()) {
			credentialId = Credentials.DEFAULT_CREDENTIAL_ID;
		}

		if (password == null || credentialId.isEmpty()) {
			throw new AdHocCommandException(Authorization.BAD_REQUEST, "Passwor cannot be null");
		}

		Form resp = new Form("result", null, null);

		authRepository.updateCredential(jid, credentialId.trim(), password);

		resp.addField(Field.fieldFixed("OK"));

		response.getElements().add(resp.getElement());
		response.completeSession();
	}

	@Override
	protected void processNoForm(AdhHocRequest request, AdHocResponse response) {
		Form form = new Form("form", getName(), null);

		form.addField(Field.fieldJidSingle(FIELD_JID, null, "The Jabber ID for the account"));
		form.addField(Field.fieldJidSingle(FIELD_CREDENTIAL_ID, null, "Credential ID"));
		form.addField(Field.fieldJidSingle(FIELD_PASSWORD, null, "Password"));

		response.startSession();
		response.getElements().add(form.getElement());
	}
}
